.modal-form {
  display: none;
  position: fixed;
  z-index: 4;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  overflow: auto;
  background-color: rgb(0,0,0,0.4);
}

.modal-form-content {
  background-color: #fefefe;
  margin: 20% 30%;
  padding: 20px;
  border: 1px solid #888;
  width: 50%;
}

.close {
  color: #aaa;
  float: right;
  font-size: 28px;
  font-weight: bold;
  text-align: center;
}

.submit-btn {
  background-color: #4CAF50;
  border: none;
  color: white;
  padding: 14px 20px;
  margin: 8px 0;
  cursor: pointer;
  font-weight: bold;
  border-radius: 4px;
}

.active {
  display: block;
}
